import { Defu } from 'defu';
import { DesignTokens, DesignToken, NuxtDesignTokens as NuxtDesignTokens$1, DesignTokensPaths, TokenHelperOptions } from '#design-tokens/types';
import * as CSSType from 'csstype';
import { Core } from 'browser-style-dictionary/types/browser';
import { Dictionary } from 'browser-style-dictionary/types/Dictionary';

declare const palette: (color: string, suffixes?: Array<string | number>, padding?: number) => DesignTokens;

interface CSSProperties extends CSSType.StandardProperties, CSSType.StandardShorthandProperties, CSSType.StandardProperties, CSSType.SvgProperties {
}
/**
 * Properties to be used in `compose({ ...properties })`
 */
declare type Properties = {
    [key in keyof CSSProperties]?: CSSProperties[key];
};
/**
 * Pseudos to be used in `compose({ ':pseudo': { ...} })`
 */
declare type Pseudos = {
    [key in CSSType.Pseudos]?: Properties;
};
declare type Variants = {
    [key: string]: Properties & Pseudos;
};
interface Compose extends Properties, Pseudos {
    variants: Variants;
}
/**
 * Compose a CSS style declaration from a type-safe JS object.
 *
 * Supports pseudo and nested selectors.
 */
declare const compose: (properties: Compose) => {
    composed: boolean;
};

declare const stubTokens: (buildPath: string, force?: boolean) => Promise<void>;
declare const getStyleDictionaryInstance: (tokens: NuxtDesignTokens, buildPath: string) => Promise<Core>;
declare const generateTokens: (tokens: NuxtDesignTokens, buildPath: string, silent?: boolean) => Promise<Dictionary>;

interface ScaleTokens extends DesignTokens {
    [key: string]: {
        default?: DesignToken | DesignTokens;
        50?: DesignToken | DesignTokens;
        100?: DesignToken | DesignTokens;
        200?: DesignToken | DesignTokens;
        300?: DesignToken | DesignTokens;
        400?: DesignToken | DesignTokens;
        500?: DesignToken | DesignTokens;
        600?: DesignToken | DesignTokens;
        700?: DesignToken | DesignTokens;
        800?: DesignToken | DesignTokens;
        900?: DesignToken | DesignTokens;
    } | DesignToken;
}
interface BreakpointsTokens extends DesignTokens {
    '2xs'?: DesignToken;
    xs?: DesignToken;
    sm?: DesignToken;
    md?: DesignToken;
    lg?: DesignToken;
    xl?: DesignToken;
    '2xl'?: DesignToken;
    '3xl'?: DesignToken;
    '4xl'?: DesignToken;
    '5xl'?: DesignToken;
}
interface FontWeightTokens extends DesignTokens {
    thin?: DesignToken;
    extraLight?: DesignToken;
    light?: DesignToken;
    regular?: DesignToken;
    medium?: DesignToken;
    semiBold?: DesignToken;
    bold?: DesignToken;
    extraBold?: DesignToken;
    black?: DesignToken;
    heavyBlack: DesignToken;
}
interface GlobalTokens extends DesignTokens {
    colors?: ScaleTokens;
    fonts?: DesignTokens;
    fontWeights?: FontWeightTokens;
    sizes?: BreakpointsTokens;
    screens?: BreakpointsTokens;
    radius?: BreakpointsTokens;
    borders?: BreakpointsTokens;
    shadows?: BreakpointsTokens;
    opacity: BreakpointsTokens;
    lineHeight?: BreakpointsTokens;
    lineHeights?: BreakpointsTokens;
    letterSpacings?: BreakpointsTokens;
    transitions?: DesignTokens;
    z?: DesignTokens;
    components?: DesignTokens;
}
interface NuxtDesignTokens extends DesignTokens, Defu<NuxtDesignTokens$1, [GlobalTokens]> {
}
interface NuxtDesignTokensConfig {
    server?: boolean;
    tokens?: NuxtDesignTokens | boolean | string;
}
interface ModuleOptions extends NuxtDesignTokensConfig {
}
interface ModuleHooks {
}
interface ModulePublicRuntimeConfig {
}
interface ModulePrivateRuntimeConfig {
    tokensDir?: string;
    server?: boolean;
    tokensFilePaths?: Array<string>;
}
declare type DeepPartial<T> = T extends object ? {
    [P in keyof T]?: DeepPartial<T[P]>;
} : T;

declare const defineTokens: (tokens: DeepPartial<NuxtDesignTokens>) => DeepPartial<NuxtDesignTokens>;
declare const $tokens: (path: DesignTokensPaths, options?: TokenHelperOptions) => any;
declare const $dt: (path: DesignTokensPaths, options?: TokenHelperOptions) => any;
declare module '@nuxt/schema' {
    interface PublicRuntimeConfig {
        designTokens?: ModulePublicRuntimeConfig;
    }
    interface RuntimeConfig {
        designTokens?: ModulePrivateRuntimeConfig;
    }
    interface NuxtConfig {
        designTokens?: Partial<ModuleOptions>;
    }
    interface NuxtOptions {
        designTokens?: ModuleOptions;
    }
}

export { $tokens as $, BreakpointsTokens as B, DeepPartial as D, FontWeightTokens as F, GlobalTokens as G, ModuleOptions as M, NuxtDesignTokens as N, ScaleTokens as S, generateTokens as a, NuxtDesignTokensConfig as b, compose as c, ModuleHooks as d, ModulePublicRuntimeConfig as e, ModulePrivateRuntimeConfig as f, getStyleDictionaryInstance as g, defineTokens as h, $dt as i, palette as p, stubTokens as s };
