import { resolveModule } from '@nuxt/kit';
import jiti from 'jiti';
import chroma from 'chroma-js';
import { kebabCase } from 'scule';
export { g as generateTokens } from './chunks/generate.mjs';
import 'fs';
import 'fs/promises';
import 'browser-style-dictionary/browser.js';
import './chunks/formats.mjs';
import 'chalk';
import 'consola';
import 'pathe';
import 'defu';

const palette = (color, suffixes = [50, 100, 200, 300, 400, 500, 600, 700, 800, 900], padding = 0.1) => {
  if (!color || typeof color !== "string") {
    throw new Error('Please provide a valid "color" string parameter');
  }
  function scalePalette(baseColor, _suffixes = suffixes, _padding = padding) {
    const colorscale = chroma.scale(["white", baseColor, "black"]).padding(padding).colors(suffixes.length);
    const colorRange = {};
    suffixes.forEach(
      (suffix, index) => colorRange[suffix] = {
        value: colorscale[index]
      }
    );
    colorRange[500] = {
      value: baseColor
    };
    return colorRange;
  }
  return {
    ...scalePalette(color),
    palette: true
  };
};

const pseudosRegex = /(::-|::|:-|:)/g;
const compose = (properties) => {
  const componentTokens = {};
  const resolveComponentTokens = (composeProperties, target, {
    prefix = "",
    pseudo = "",
    variant = ""
  } = {}) => {
    const createValue = (key, value, options) => {
      const rawProperty = kebabCase(key);
      const property = (options?.prefix || "") + rawProperty;
      delete options.prefix;
      if (typeof value !== "object") {
        target[property] = {
          value,
          property: rawProperty,
          ...options
        };
      } else {
        target[property] = {
          ...value,
          property: rawProperty,
          ...options
        };
      }
    };
    Object.entries(composeProperties).forEach(([key, value]) => {
      if (pseudosRegex.test(key)) {
        const pseudoPrefix = key.replace(pseudosRegex, "");
        resolveComponentTokens(
          value,
          target,
          {
            prefix: `${pseudoPrefix}-`,
            pseudo: key
          }
        );
        return;
      }
      if (key === "variants") {
        Object.entries(value).forEach(
          ([_variantKey, _variantValue]) => {
            if (!target.variants) {
              target.variants = {};
            }
            if (!target.variants[_variantKey]) {
              target.variants[_variantKey] = {};
            }
            resolveComponentTokens(_variantValue, target.variants[_variantKey], { variant: _variantKey });
          }
        );
        return;
      }
      createValue(key, value, { prefix, pseudo, variant });
    });
    return componentTokens;
  };
  const component = resolveComponentTokens(properties, componentTokens);
  return {
    ...component,
    composed: true
  };
};

const defineTokens = (tokens) => tokens;
const $tokens = (path, options = {
  key: "variable",
  flatten: true,
  silent: false
}) => {
  const module = resolveModule(`${globalThis.__nuxtDesignTokensBuildDir__}index.ts`);
  const { $dt: $dt2 } = jiti(import.meta.url, { cache: false, requireCache: false, v8cache: false })(module);
  return $dt2(path, options);
};
const $dt = $tokens;

export { $dt, $tokens, compose, defineTokens, palette };
